==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/ConnectorCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Connector;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionreferenceRequest;
import microsoft.dynamics.crm.entity.request.ConnectorRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class ConnectorCollectionRequest extends CollectionPageEntityRequest<Connector, ConnectorRequest>{

    protected ContextPath contextPath;

    public ConnectorCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Connector.class, cp -> new ConnectorRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest connector_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("connector_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest connector_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("connector_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest connector_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("connector_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest connector_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("connector_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest connector_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("connector_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest connector_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("connector_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest connector_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("connector_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest connector_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("connector_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest connector_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("connector_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest connector_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("connector_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest connector_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("connector_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest connector_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("connector_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest connector_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("connector_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest connector_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("connector_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest connector_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("connector_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest connector_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("connector_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public ConnectionreferenceCollectionRequest connector_connectionreference() {
        return new ConnectionreferenceCollectionRequest(contextPath.addSegment("connector_connectionreference"), Optional.empty());
    }

    public ConnectionreferenceRequest connector_connectionreference(String connectionreferenceid) {
        return new ConnectionreferenceRequest(contextPath.addSegment("connector_connectionreference").addKeys(new NameValue(connectionreferenceid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/ConnectorCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Connector;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionreferenceRequest;
import microsoft.dynamics.crm.entity.request.ConnectorRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class ConnectorCollectionRequest extends CollectionPageEntityRequest<Connector, ConnectorRequest>{

    protected ContextPath contextPath;

    public ConnectorCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Connector.class, cp -> new ConnectorRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest connector_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("connector_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest connector_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("connector_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest connector_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("connector_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest connector_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("connector_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest connector_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("connector_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest connector_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("connector_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest connector_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("connector_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest connector_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("connector_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest connector_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("connector_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest connector_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("connector_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest connector_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("connector_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest connector_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("connector_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest connector_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("connector_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest connector_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("connector_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest connector_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("connector_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest connector_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("connector_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public ConnectionreferenceCollectionRequest connector_connectionreference() {
        return new ConnectionreferenceCollectionRequest(contextPath.addSegment("connector_connectionreference"), Optional.empty());
    }

    public ConnectionreferenceRequest connector_connectionreference(String connectionreferenceid) {
        return new ConnectionreferenceRequest(contextPath.addSegment("connector_connectionreference").addKeys(new NameValue(connectionreferenceid.toString())), Optional.empty());
    }

}
